@@ -577,7 +577,7 @@ compare_clusterings <- function(series = NULL, types = c("p", "h", "f", "t"), ..
     # Matrix allocation
     # ==============================================================================================
 
-    allocate_gcm <- allocate_logs <- allocate_dba <- FALSE
+    allocate_sdtwc <- allocate_cm <- allocate_gcm <- allocate_logs <- allocate_dba <- FALSE
     if (any(types != "tadpole")) {
         allocate_gcm <- any(sapply(setdiff(types, "tadpole"), function(type) {
             any(grepl("^dtw_basic$|^dtw_lb$", configs[[type]]$distance, ignore.case = TRUE)) &&
@@ -594,7 +594,17 @@ compare_clusterings <- function(series = NULL, types = c("p", "h", "f", "t"), ..
                 !("gcm_centroid" %in% colnames(configs[[type]]))
         }))
 
-        if (allocate_gcm || allocate_logs || allocate_dba)
+        allocate_cm <- any(sapply(types, function(type) {
+            any(grepl("^sdtw$", configs[[type]]$distance, ignore.case = TRUE)) &&
+                !("cm_distance" %in% colnames(configs[[type]]))
+        }))
+
+        allocate_sdtwc <- any(sapply(types, function(type) {
+            any(grepl("^sdtw_cent$", configs[[type]]$centroid, ignore.case = TRUE)) &&
+                !("cm_centroid" %in% colnames(configs[[type]]))
+        }))
+
+        if (allocate_gcm || allocate_logs || allocate_dba || allocate_cm || allocate_sdtwc)
             N <- max(sapply(processed_series, function(series_by_type) {
                 max(sapply(series_by_type, function(series) {
                     max(sapply(series, NROW))
@@ -607,12 +617,24 @@ compare_clusterings <- function(series = NULL, types = c("p", "h", "f", "t"), ..
             else if (allocate_gcm)
                 dots$gcm <- matrix(0, 2L, N + 1L)
 
-        } else allocate_dba <- allocate_gcm <- FALSE
+        } else { allocate_dba <- allocate_gcm <- FALSE }
 
         if (allocate_logs && is.null(dots$logs))
             dots$logs <- matrix(0, N + 1L, 3L)
         else
             allocate_logs <- FALSE
+
+        if (allocate_cm && is.null(dots$cm))
+            dots$cm <- matrix(0, N + 1L, N + 1L)
+        else
+            allocate_cm <- FALSE
+
+        if (allocate_sdtwc && (is.null(dots$cm) || is.null(dots$dm) || is.null(dots$em))) {
+            dots$cm <- matrix(0, N + 2L, N + 2L)
+            dots$dm <- matrix(0, N + 1L, N + 1L)
+            dots$em <- matrix(0, 2L, N + 2L)
+
+        } else allocate_sdtwc <- FALSE
     }
 
     # ==============================================================================================
@@ -652,7 +674,7 @@ compare_clusterings <- function(series = NULL, types = c("p", "h", "f", "t"), ..
             assign(custom_centroid, get_from_callers(custom_centroid, "function"))
 
         export <- c("trace", "score.clus", "return.objects",
-                    "dots", "allocate_gcm", "allocate_logs", "allocate_dba",
+                    "dots", "allocate_gcm", "allocate_logs", "allocate_dba", "allocate_cm", "allocate_sdtwc",
                     "centroids_included",
                     "check_consistency", "enlist", "subset_dots", "get_from_callers", "setnames_inplace",
                     custom_preprocs, custom_centroids)
@@ -767,7 +789,7 @@ compare_clusterings <- function(series = NULL, types = c("p", "h", "f", "t"), ..
                 # do not specify centroid
                 tsc <- do.call(tsclust, this_args, TRUE)
 
-            } else if (centroid_char %in% centroids_included) {
+            } else if (type %in% c("partitional", "fuzzy") && centroid_char %in% centroids_included) {
                 # with included centroid
                 tsc <- do.call(tsclust,
                                enlist(centroid = centroid_char, dots = this_args),
@@ -807,6 +829,26 @@ compare_clusterings <- function(series = NULL, types = c("p", "h", "f", "t"), ..
                     })
                 }
 
+                if (allocate_cm) {
+                    tsc@dots$cm <- NULL
+                    tsc@args <- lapply(tsc@args, function(arg) {
+                        arg$cm <- NULL
+                        arg
+                    })
+                }
+
+                if (allocate_sdtwc) {
+                    tsc@dots$cm <- NULL
+                    tsc@dots$dm <- NULL
+                    tsc@dots$em <- NULL
+                    tsc@args <- lapply(tsc@args, function(arg) {
+                        arg$cm <- NULL
+                        arg$dm <- NULL
+                        arg$em <- NULL
+                        arg
+                    })
+                }
+
                 tsc
             })
 
