@@ -1,4 +1,4 @@
-context("\tHierarchical")
+context("    Hierarchical")
 
 # ==================================================================================================
 # setup
@@ -78,6 +78,13 @@ test_that("Hierarchical clustering works as expected.", {
                        control = hierarchical_control(method = "all"))
     hc_cent <- lapply(hc_cent, reset_nondeterministic)
     assign("hc_cent", hc_cent, persistent)
+
+    hc_cent2 <- tsclust(data_subset, type = "hierarchical", k = 2L,
+                        distance = "sbd", centroid = sdtw_cent,
+                        seed = 320)
+    hc_cent2 <- reset_nondeterministic(hc_cent2)
+    expect_identical(hc_cent2@centroid, "sdtw_cent")
+    assign("hc_cent2", hc_cent2, persistent)
 })
 
 # ==================================================================================================
@@ -90,6 +97,7 @@ test_that("A valid custom hierarchical function works as expected.", {
     hc_diana <- tsclust(data, type = "hierarchical", k = 20L,
                         distance = "sbd",
                         control = hierarchical_control(method = diana))
+    expect_s4_class(hc_diana, "HierarchicalTSClusters")
     hc_diana <- reset_nondeterministic(hc_diana)
     hc_diana$call <- NULL
     assign("hc_diana", hc_diana, persistent)
