@@ -7,23 +7,20 @@ context("Parallel tests")
 chk <- Sys.getenv("_R_CHECK_LIMIT_CORES_", "")
 
 if (nzchar(chk) && chk == "TRUE") {
-    ## use 2 cores in CHECK/Travis/AppVeyor
+    # use 2 cores in CHECK/Travis/AppVeyor
     num_workers <- 2L
 } else {
-    ## use all cores in devtools::test()
+    # use all cores in devtools::test()
     num_workers <- parallel::detectCores()
 }
 
-## see https://github.com/hadley/testthat/issues/129
-Sys.setenv("R_TESTS" = "")
-
 test_that("Parallel computation gives the same results as sequential", {
     skip_on_cran()
 
     if (getOption("dtwclust_skip_par_tests", FALSE))
         skip("Parallel tests disabled explicitly.")
 
-    cat("with", num_workers, "workers\n")
+    cat(" (with", num_workers, "workers)\n")
 
     require(doParallel)
 
@@ -31,13 +28,13 @@ test_that("Parallel computation gives the same results as sequential", {
     invisible(clusterEvalQ(cl, library(dtwclust)))
     registerDoParallel(cl)
 
-    ## Filter excludes files that have "parallel" in them, otherwise it would be recursive
-    test_dir("./", filter = "parallel", invert = TRUE)
+    # Filter excludes files that have "parallel" in them, otherwise it would be recursive
+    res <- test_dir("./", filter = "parallel", invert = TRUE)
+    expect_s3_class(res, "testthat_results")
 
     stopCluster(cl)
     stopImplicitCluster()
     registerDoSEQ()
-
     rm(cl)
 })
 
@@ -49,14 +46,15 @@ test_that("Parallel FORK computation gives the same results as sequential", {
     if (getOption("dtwclust_skip_par_tests", FALSE))
         skip("Parallel tests disabled explicitly.")
 
-    ## Also test FORK in Linux
-    cat("Test FORKs:\n")
+    # Also test FORK in Linux
+    cat(" - Test FORKs:\n")
 
     cl <- makeCluster(num_workers - 1L, "FORK")
     registerDoParallel(cl)
 
-    ## Filter excludes files that have "parallel" in them, otherwise it would be recursive
-    test_dir("./", filter = "parallel", invert = TRUE)
+    # Filter excludes files that have "parallel" in them, otherwise it would be recursive
+    res <- test_dir("./", filter = "parallel", invert = TRUE)
+    expect_s3_class(res, "testthat_results")
 
     stopCluster(cl)
     stopImplicitCluster()
